@@ -1,7 +1,10 @@
 """Main MP3CombineAndSplit module."""
+import os
+
 import eyed3
 from eyed3.mimetype import guessMimetype
 from eyed3.mp3 import MIME_TYPES as MP3_MIME_TYPES
+import natsort
 from os import listdir
 from os.path import isfile, join
 from pydub import AudioSegment
@@ -70,21 +73,42 @@ class MP3CombineAndSplit(object):
     def find_mp3_files_in_input_directory(self):
         mp3files = []
         mp3_file_by_track_num = dict()
-        for i, input_file in enumerate(sorted(listdir(self.input_directory))):
+        sort_order_index = 0
+        for input_file in natsort.natsorted(listdir(self.input_directory)):
             file_path = join(self.input_directory, input_file)
             if isfile(file_path):
                 mime_type = guessMimetype(file_path)
                 if mime_type in MP3_MIME_TYPES:
+                    sort_order_index = sort_order_index + 1
                     mp3_file_object = eyed3.load(file_path)
-                    mp3_file_object_track_num = mp3_file_object.tag.track_num
-                    if mp3_file_object_track_num[0]:
-                        self.album = mp3_file_object.tag.album
-                        self.artist = mp3_file_object.tag.artist
-                        mp3_file_by_track_num[mp3_file_object_track_num] = file_path
-                    else:
+                    try:
+                        mp3_file_object_track_num = mp3_file_object.tag.track_num
+                    except AttributeError:
                         print(
-                            f"{file_path} not included as it does not have a valid track number"
+                            f"{file_path} does not have a valid track number - using sort order index {sort_order_index} instead"
                         )
+                        mp3_file_object_track_num = (sort_order_index, None)
+
+                    try:
+                        self.album = mp3_file_object.tag.album
+                    except AttributeError:
+                        fallback_album = os.path.basename(self.input_directory)
+                        print(
+                            f"{file_path} does not have a valid album - using {fallback_album} instead"
+                        )
+                        self.album = fallback_album
+
+                    try:
+                        self.artist = mp3_file_object.tag.artist
+                    except AttributeError:
+                        fallback_artist = os.path.basename(self.input_directory)
+                        print(
+                            f"{file_path} does not have a valid artist - using {fallback_artist} instead"
+                        )
+                        self.artist = fallback_artist
+
+                    mp3_file_by_track_num[mp3_file_object_track_num] = file_path
+
         sorted_track_nums = sorted(mp3_file_by_track_num.keys())
         for sorted_track_num in sorted_track_nums:
             mp3files.append(mp3_file_by_track_num[sorted_track_num])
